@@ -2,8 +2,8 @@ from sm.misc.fn_cache import *
 from sm.misc.deser import *
 from sm.misc.funcs import *
 from sm.misc.exp_manager import *
-from sm.misc.ontology_namespace import *
 from sm.misc.logger import *
+from sm.misc.parallel import Parallel, ParallelFnWrapper
 
 import sm.misc.graph as G
 
