@@ -20,6 +20,9 @@ from tqdm.auto import tqdm
 import importlib
 
 
+V = TypeVar("V")
+
+
 def str2bool(x):
     assert x in {"True", "False", "true", "false", "null"}
     if x == "null":
@@ -39,11 +42,16 @@ def str2int(x):
     return int(x)
 
 
-def percentage(a, b):
+def assert_not_null(x: Optional[V]) -> V:
+    assert x is not None
+    return x
+
+
+def percentage(a: Union[float, int], b: Union[float, int]) -> str:
     return "%.2f%% (%d/%d)" % (a * 100 / b, a, b)
 
 
-def filter_duplication(lst: List[Any], key_fn: Callable[[Any], Any] = None):
+def filter_duplication(lst: List[Any], key_fn: Optional[Callable[[Any], Any]] = None):
     key_fn = key_fn or identity_func
     keys = set()
     new_lst = []
@@ -105,7 +113,7 @@ def get_latest_path(path: Union[str, Path]) -> Optional[str]:
 def auto_wrap(
     word: str,
     max_char_per_line: int,
-    delimiters: List[str] = None,
+    delimiters: Optional[List[str]] = None,
     camelcase_split: bool = True,
 ) -> str:
     """
